summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/skyobject.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/skyobject.cpp')
-rw-r--r--kstars/kstars/skyobject.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/kstars/kstars/skyobject.cpp b/kstars/kstars/skyobject.cpp
index 5ea5036d..18decc7c 100644
--- a/kstars/kstars/skyobject.cpp
+++ b/kstars/kstars/skyobject.cpp
@@ -205,7 +205,7 @@ TQTime SkyObject::transitTimeUT( const KStarsDateTime &dt, const GeoLocation *ge
//dt0 is the first guess at the transit time.
KStarsDateTime dt0 = dt.addSecs( dSec );
//recompute object's position at UT0 and then find
//transit time of this refined position
SkyPoint sp = recomputeCoords( dt0, geo );
const dms *ram = sp.ra0();
@@ -342,32 +342,32 @@ TQString SkyObject::messageFromTitle( const TQString &imageTitle ) {
TQString message = imageTitle;
//HST Image
- if ( imageTitle == i18n( "Show HST Image" ) || imageTitle.contains("HST") ) {
- message = i18n( "%1: Hubble Space Telescope, operated by STScI for NASA [public domain]" ).arg( longname() );
+ if ( imageTitle == i18n( "Show HST Image" ) || imageTitle.tqcontains("HST") ) {
+ message = i18n( "%1: Hubble Space Telescope, operated by STScI for NASA [public domain]" ).tqarg( longname() );
//Spitzer Image
- } else if ( imageTitle.contains( i18n( "Show Spitzer Image" ) ) ) {
- message = i18n( "%1: Spitzer Space Telescope, courtesy NASA/JPL-Caltech [public domain]" ).arg( longname() );
+ } else if ( imageTitle.tqcontains( i18n( "Show Spitzer Image" ) ) ) {
+ message = i18n( "%1: Spitzer Space Telescope, courtesy NASA/JPL-Caltech [public domain]" ).tqarg( longname() );
//SEDS Image
} else if ( imageTitle == i18n( "Show SEDS Image" ) ) {
- message = i18n( "%1: SEDS, http://www.seds.org [free for non-commercial use]" ).arg( longname() );
+ message = i18n( "%1: SEDS, http://www.seds.org [free for non-commercial use]" ).tqarg( longname() );
//Kitt Peak AOP Image
} else if ( imageTitle == i18n( "Show KPNO AOP Image" ) ) {
- message = i18n( "%1: Advanced Observing Program at Kitt Peak National Observatory [free for non-commercial use; no physical reproductions]" ).arg( longname() );
+ message = i18n( "%1: Advanced Observing Program at Kitt Peak National Observatory [free for non-commercial use; no physical reproductions]" ).tqarg( longname() );
//NOAO Image
- } else if ( imageTitle.contains( i18n( "Show NOAO Image" ) ) ) {
- message = i18n( "%1: National Optical Astronomy Observatories and AURA [free for non-commercial use]" ).arg( longname() );
+ } else if ( imageTitle.tqcontains( i18n( "Show NOAO Image" ) ) ) {
+ message = i18n( "%1: National Optical Astronomy Observatories and AURA [free for non-commercial use]" ).tqarg( longname() );
//VLT Image
- } else if ( imageTitle.contains( "VLT" ) ) {
- message = i18n( "%1: Very Large Telescope, operated by the European Southern Observatory [free for non-commercial use; no reproductions]" ).arg( longname() );
+ } else if ( imageTitle.tqcontains( "VLT" ) ) {
+ message = i18n( "%1: Very Large Telescope, operated by the European Southern Observatory [free for non-commercial use; no reproductions]" ).tqarg( longname() );
//All others
} else if ( imageTitle.startsWith( i18n( "Show" ) ) ) {
- message = imageTitle.mid( imageTitle.find( " " ) + 1 ); //eat first word, "Show"
+ message = imageTitle.mid( imageTitle.tqfind( " " ) + 1 ); //eat first word, "Show"
message = longname() + ": " + message;
}
@@ -383,7 +383,7 @@ void SkyObject::saveUserLog( const TQString &newLog ) {
//Do nothing if new log is the "default" message
//(keep going if new log is empty; we'll want to delete its current entry)
- if ( newLog == (i18n("Record here observation logs and/or data on %1.").arg(name())) || newLog.isEmpty() )
+ if ( newLog == (i18n("Record here observation logs and/or data on %1.").tqarg(name())) || newLog.isEmpty() )
return;
// header label
@@ -408,9 +408,9 @@ void SkyObject::saveUserLog( const TQString &newLog ) {
int startIndex, endIndex;
TQString sub;
- startIndex = logs.find(KSLabel);
+ startIndex = logs.tqfind(KSLabel);
sub = logs.mid (startIndex);
- endIndex = sub.find("[KSLogEnd]");
+ endIndex = sub.tqfind("[KSLogEnd]");
logs.remove(startIndex, endIndex + 11);
}
@@ -205,7 +205,7 @@ TQTime SkyObject::transitTimeUT( const KStarsDateTime &dt, const GeoLocation *ge
//dt0 is the first guess at the transit time.
KStarsDateTime dt0 = dt.addSecs( dSec );
- //recompute object's position at UT0 and then find
+ //recompute object's position at UT0 and then tqfind
//transit time of this refined position
SkyPoint sp = recomputeCoords( dt0, geo );